summaryrefslogtreecommitdiffstats
path: root/konsole/konsole/konsolebookmarkmenu.cpp
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2024-01-12 10:51:50 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2024-01-16 10:03:43 +0900
commita4241b7911d2e0b36edfb02f616b8b282050c0ec (patch)
tree316c9a3298857645d5da57b682fce707c8e2a907 /konsole/konsole/konsolebookmarkmenu.cpp
parentf9d06cee3d2b4ffe415b1d52c9ad5575643a9e34 (diff)
downloadtdebase-a4241b7911d2e0b36edfb02f616b8b282050c0ec.tar.gz
tdebase-a4241b7911d2e0b36edfb02f616b8b282050c0ec.zip
Use new TQ_METHOD, TQ_SIGNAL, TQ_SLOT defines
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'konsole/konsole/konsolebookmarkmenu.cpp')
-rw-r--r--konsole/konsole/konsolebookmarkmenu.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/konsole/konsole/konsolebookmarkmenu.cpp b/konsole/konsole/konsolebookmarkmenu.cpp
index 77b86882b..d199808df 100644
--- a/konsole/konsole/konsolebookmarkmenu.cpp
+++ b/konsole/konsole/konsolebookmarkmenu.cpp
@@ -36,14 +36,14 @@ KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
/*
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonsoleBookmarkMenu::slotAboutToShow().
* They are named differently because the TQT_SLOT() macro thinks we want
* KonsoleBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?
*/
- disconnect( _parentMenu, TQT_SIGNAL( aboutToShow() ), this,
- TQT_SLOT( slotAboutToShow() ) );
- connect( _parentMenu, TQT_SIGNAL( aboutToShow() ),
- TQT_SLOT( slotAboutToShow2() ) );
+ disconnect( _parentMenu, TQ_SIGNAL( aboutToShow() ), this,
+ TQ_SLOT( slotAboutToShow() ) );
+ connect( _parentMenu, TQ_SIGNAL( aboutToShow() ),
+ TQ_SLOT( slotAboutToShow2() ) );
}
/*
@@ -113,7 +113,7 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
// kdDebug(1203) << "Creating URL bookmark menu item for " << bm.text() << endl;
// create a normal URL item, with ID as a name
TDEAction * action = new TDEAction( text, bm.icon(), 0,
- this, TQT_SLOT( slotBookmarkSelected() ),
+ this, TQ_SLOT( slotBookmarkSelected() ),
m_actionCollection, bm.url().url().utf8() );
action->setStatusText( bm.url().prettyURL() );
@@ -36,14 +36,14 @@ KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonsoleBookmarkMenu::slotAboutToShow().
- * They are named differently because the TQT_SLOT() macro thinks we want
+ * They are named differently because the TQ_SLOT() macro thinks we want
* KonsoleBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?